@@ -42,12 +42,14 @@ class File:
             for i in range(1, nrow):
                 item1 = []
                 item = {}
+                item2 = ''
                 for j in range(0, len(ths)):
                     cell = table.cell_value(i, j)
                     item[ths[j]] = cell
                     item1.append(cell)
+                    item2 += '%s\t' % cell
                 if to_string:
-                    strings += '\n%s' % ('\t'.join(item1))
+                    strings += '\n%s' % (item2.strip('\t'))
                 items.append(item)
                 items1.append(item1)
             if to_string:
